Class: Aws::MarketplaceReporting::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MarketplaceReporting::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-marketplacereporting/client.rb,
sig/client.rbs
Overview
An API client for MarketplaceReporting. To construct a client, you need to configure a :region and :credentials.
client = Aws::MarketplaceReporting::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _GetBuyerDashboardResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_buyer_dashboard(params = {}) ⇒ Types::GetBuyerDashboardOutput
Generates an embedding URL for an Amazon QuickSight dashboard for an anonymous user.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-marketplacereporting/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
607 608 609 |
# File 'lib/aws-sdk-marketplacereporting/client.rb', line 607 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
610 611 612 |
# File 'lib/aws-sdk-marketplacereporting/client.rb', line 610 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/aws-sdk-marketplacereporting/client.rb', line 580 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MarketplaceReporting') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-marketplacereporting' context[:gem_version] = '1.24.0' Seahorse::Client::Request.new(handlers, context) end |
#get_buyer_dashboard(params = {}) ⇒ Types::GetBuyerDashboardOutput
Generates an embedding URL for an Amazon QuickSight dashboard for an anonymous user.
procurement-insights.marketplace.amazonaws.com) feature.
The following rules apply to a generated URL:
-
It contains a temporary bearer token, valid for 5 minutes after it is generated. Once redeemed within that period, it cannot be re-used again.
-
It has a session lifetime of one hour. The 5-minute validity period runs separately from the session lifetime.
88 |
# File 'sig/client.rbs', line 88
def get_buyer_dashboard: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
600 601 602 |
# File 'lib/aws-sdk-marketplacereporting/client.rb', line 600 def waiter_names [] end |